@@ -1,7 +1,6 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
-   Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.7
+   SPDX-License-Identifier: ISC
   ---------------------------------------------------------------------------*)
 
 open Bos_setup
@@ -159,27 +158,9 @@ module Pp = struct
   let name = Fmt.(styled `Bold string)
   let version = Fmt.(styled `Cyan string)
   let commit = Fmt.(styled `Yellow string)
-  let dirty = Fmt.(styled_unit `Red "dirty")
+  let dirty = Fmt.(styled `Red (any "dirty"))
   let path = Fmt.(styled `Bold Fpath.pp)
   let status ppf = function
-  | `Ok -> Fmt.(brackets @@ styled_unit `Green " OK ") ppf ()
-  | `Fail -> Fmt.(brackets @@ styled_unit `Red "FAIL") ppf ()
+  | `Ok -> Fmt.(brackets @@ styled `Green (any " OK ")) ppf ()
+  | `Fail -> Fmt.(brackets @@ styled `Red (any "FAIL")) ppf ()
 end
-
-
-
-(*---------------------------------------------------------------------------
-   Copyright (c) 2016 Daniel C. Bünzli
-
-   Permission to use, copy, modify, and/or distribute this software for any
-   purpose with or without fee is hereby granted, provided that the above
-   copyright notice and this permission notice appear in all copies.
-
-   THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-   WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-   MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-   ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-   WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-   ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-   OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
-  ---------------------------------------------------------------------------*)
